package com.link.core.cache;

import com.google.common.util.concurrent.ThreadFactoryBuilder;
import com.link.core.basic.thread.LinkThreadPoolExecutor;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.SynchronousQueue;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.TimeUnit;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

@Configuration
public class LinkThreadCacheConfig {
   @Bean
   @Primary
   @ConditionalOnMissingBean({LinkThreadPoolExecutor.class})
   public LinkThreadPoolExecutor getLinkCacheThreadPoolExecutor() {
      ThreadFactory threadFactory = (new ThreadFactoryBuilder()).setNameFormat("CORE-%d").build();
      LinkThreadPoolExecutor linkThreadPoolExecutor = new LinkThreadPoolExecutor(20, 2000, 10L, TimeUnit.SECONDS, new SynchronousQueue(), threadFactory);
      return linkThreadPoolExecutor;
   }

   @Bean(
      name = {"LinkThreadPoolExecutorEsExport"}
   )
   public LinkThreadPoolExecutor getLinkThreadPoolExecutorEsExport() {
      ThreadFactory threadFactory = (new ThreadFactoryBuilder()).setNameFormat("ES-EXPORT-%d").build();
      LinkThreadPoolExecutor linkThreadPoolExecutor = new LinkThreadPoolExecutor(20, 2000, 10L, TimeUnit.SECONDS, new LinkedBlockingQueue(), threadFactory);
      return linkThreadPoolExecutor;
   }
}
